==> nutrition-ai-3.2.1-sources.jar: ai/passio/passiosdk/passiofood/file/PassioFoodFileManager.kt <==
package ai.passio.passiosdk.passiofood.file

import ai.passio.passiosdk.BuildConfig
import ai.passio.passiosdk.core.config.SDKFileType
import ai.passio.passiosdk.core.file.PassioFileManager
import ai.passio.passiosdk.core.utils.FileUtil
import ai.passio.passiosdk.passiofood.PassioSDKImpl
import ai.passio.passiosdk.passiofood.config.PassioSDKFileConfig
import ai.passio.passiosdk.passiofood.config.passio_FoodNet_HNN_ENv2
import ai.passio.passiosdk.passiofood.config.passio_FoodNet_SSD_HNN
import ai.passio.passiosdk.passiofood.config.passio_FoodNet_Yolo
import ai.passio.passiosdk.passiofood.config.passio_dataset
import ai.passio.passiosdk.passiofood.config.passio_metadata
import ai.passio.passiosdk.passiofood.config.passio_nutrition_HNN
import ai.passio.passiosdk.passiofood.config.passio_ocr_vectorize
import android.content.Context
import android.util.Log
import java.io.File

internal class PassioFoodFileManager(
    sdkFileConfig: PassioSDKFileConfig
) : PassioFileManager(sdkFileConfig) {

    override fun getAvailableFileTypes(): List<SDKFileType> {
        val availableTypes = mutableListOf<SDKFileType>()

        availableTypes.add(passio_dataset)
        availableTypes.add(passio_FoodNet_SSD_HNN)
        availableTypes.add(passio_FoodNet_HNN_ENv2)

        availableTypes.add(passio_ocr_vectorize)

        return availableTypes
    }

    override fun printVersions(context: Context) {
        val availableTypes = getAvailableFileTypes()
        val installedVersion = getInstalledVersion(context)
        Log.i(PassioFileManager::class.java.simpleName, "Installed: $installedVersion")

        val databaseFile = getStoredFile(context, passio_nutrition_HNN)
        val installedDBVersion = if (databaseFile != null) getVersionFromFile(databaseFile) else 0
        Log.i(PassioFileManager::class.java.simpleName, "Installed DB: $installedDBVersion")

        val shippedFiles = getFilesFromAssets(context, availableTypes)
        val shippedVersion = if (shippedFiles.isNotEmpty()) {
            shippedFiles.first().split(File.pathSeparator).last().split(".")[1].toInt()
        } else {
            0
        }
        Log.i(PassioFileManager::class.java.simpleName, "Shipped: $shippedVersion")
    }

    fun getShippedDBVersion(context: Context): Int {
        FileUtil.listAssetFiles(context.assets, "").forEach { fileName ->
            if (fileName.startsWith(passio_nutrition_HNN.name)) {
                return fileName.split(".")[1].toInt()
            }
        }

        return 0
    }

    fun getFilesMissingFromFolder(
        context: Context,
        parent: String,
        requiredFiles: List<SDKFileType>,
        compressed: Boolean = false
    ): List<String> {
        val missingFiles = mutableListOf<String>()
        if (compressed) {
            missingFiles.addAll(requiredFiles.map { "${it.name}.${PassioSDKImpl.FILE_VERSION}.passiosecure2" })
        } else {
            missingFiles.addAll(requiredFiles.map { "${it.name}.${PassioSDKImpl.FILE_VERSION}.passiosecure" })
        }

        val root = File(
            context.cacheDir.absolutePath + File.separator +
                    CACHE_ROOT + File.separator +
                    BuildConfig.SDK_TYPE.lowercase() + File.separator +
                    parent
        )
        if (!root.exists() && !root.isDirectory) {
            return missingFiles
        }

        root.listFiles()?.forEach { file ->
            requiredFiles.forEach { sdkFileType ->
                if (file.name.startsWith(sdkFileType.name)) {
                    missingFiles.remove(file.name)
                }
            }
        }

        return missingFiles
    }
}

==> nutrition-ai-3.2.1-1-sources.jar: ai/passio/passiosdk/passiofood/file/PassioFoodFileManager.kt <==
package ai.passio.passiosdk.passiofood.file

import ai.passio.passiosdk.BuildConfig
import ai.passio.passiosdk.core.config.SDKFileType
import ai.passio.passiosdk.core.file.PassioFileManager
import ai.passio.passiosdk.core.utils.FileUtil
import ai.passio.passiosdk.passiofood.PassioSDKImpl
import ai.passio.passiosdk.passiofood.config.PassioSDKFileConfig
import ai.passio.passiosdk.passiofood.config.passio_FoodNet_HNN_ENv2
import ai.passio.passiosdk.passiofood.config.passio_FoodNet_SSD_HNN
import ai.passio.passiosdk.passiofood.config.passio_FoodNet_Yolo
import ai.passio.passiosdk.passiofood.config.passio_dataset
import ai.passio.passiosdk.passiofood.config.passio_metadata
import ai.passio.passiosdk.passiofood.config.passio_nutrition_HNN
import ai.passio.passiosdk.passiofood.config.passio_ocr_vectorize
import android.content.Context
import android.util.Log
import java.io.File

internal class PassioFoodFileManager(
    sdkFileConfig: PassioSDKFileConfig
) : PassioFileManager(sdkFileConfig) {

    override fun getAvailableFileTypes(): List<SDKFileType> {
        val availableTypes = mutableListOf<SDKFileType>()

        availableTypes.add(passio_dataset)
        availableTypes.add(passio_FoodNet_SSD_HNN)
        availableTypes.add(passio_FoodNet_HNN_ENv2)

        availableTypes.add(passio_ocr_vectorize)

        return availableTypes
    }

    override fun printVersions(context: Context) {
        val availableTypes = getAvailableFileTypes()
        val installedVersion = getInstalledVersion(context)
        Log.i(PassioFileManager::class.java.simpleName, "Installed: $installedVersion")

        val databaseFile = getStoredFile(context, passio_nutrition_HNN)
        val installedDBVersion = if (databaseFile != null) getVersionFromFile(databaseFile) else 0
        Log.i(PassioFileManager::class.java.simpleName, "Installed DB: $installedDBVersion")

        val shippedFiles = getFilesFromAssets(context, availableTypes)
        val shippedVersion = if (shippedFiles.isNotEmpty()) {
            shippedFiles.first().split(File.pathSeparator).last().split(".")[1].toInt()
        } else {
            0
        }
        Log.i(PassioFileManager::class.java.simpleName, "Shipped: $shippedVersion")
    }

    fun getShippedDBVersion(context: Context): Int {
        FileUtil.listAssetFiles(context.assets, "").forEach { fileName ->
            if (fileName.startsWith(passio_nutrition_HNN.name)) {
                return fileName.split(".")[1].toInt()
            }
        }

        return 0
    }

    fun getFilesMissingFromFolder(
        context: Context,
        parent: String,
        requiredFiles: List<SDKFileType>,
        compressed: Boolean = false
    ): List<String> {
        val missingFiles = mutableListOf<String>()
        if (compressed) {
            missingFiles.addAll(requiredFiles.map { "${it.name}.${PassioSDKImpl.FILE_VERSION}.passiosecure2" })
        } else {
            missingFiles.addAll(requiredFiles.map { "${it.name}.${PassioSDKImpl.FILE_VERSION}.passiosecure" })
        }

        val root = File(
            context.cacheDir.absolutePath + File.separator +
                    CACHE_ROOT + File.separator +
                    CACHE_NUTRITION_FOLDER + File.separator +
                    parent
        )
        if (!root.exists() && !root.isDirectory) {
            return missingFiles
        }

        root.listFiles()?.forEach { file ->
            requiredFiles.forEach { sdkFileType ->
                if (file.name.startsWith(sdkFileType.name)) {
                    missingFiles.remove(file.name)
                }
            }
        }

        return missingFiles
    }
}
